@@ -1,7 +1,15 @@
-from typing_extensions import Final
-import os
-import platform
-import logging
+from sls_sdk.lib.imports import internally_imported
+
+with internally_imported():
+    import os
+    import platform
+    import logging
+    import sys
+
+    if sys.version_info >= (3, 8):
+        from typing import Final
+    else:
+        from typing_extensions import Final
 
 from sls_sdk.lib.trace import TraceSpan
 from sls_sdk.lib.timing import _DIFF
